import logging
import colorlog
from colorlog import default_log_colors, ColoredFormatter


class PackagePathFormatter(ColoredFormatter):
    def format(self, record):
        if hasattr(record, 'module'):
            package_path = record.module.replace('.', '/')
        else:
            package_path = ""

        record.package_filepath = f"{package_path}.py" if package_path else record.filename

        return super().format(record)


def setup_logging(level=logging.INFO):
    # 创建一个日志记录器
    logging.basicConfig(style='%')
    logger = logging.getLogger()
    logger.setLevel(level)
    logger.handlers = []

    # 创建一个控制台处理器
    console_handler = logging.StreamHandler()
    console_handler.setLevel(logging.INFO)  # 设置处理器的日志级别
    console_handler.setFormatter(PackagePathFormatter(
        '%(log_color)s %(asctime)s - %(name)s:%(lineno)d - %(levelname)s - %(message)s',
        log_colors=default_log_colors
    ))
    logger.addHandler(console_handler)



import base64


def base_encode(text: str):
    encoded_bytes = base64.b64encode(text.encode('utf-8'))
    encoded_str = encoded_bytes.decode('ascii')
    return encoded_str


def base_decode(text: str):
    decoded_bytes = base64.b64decode(text)
    decoded_text = decoded_bytes.decode('utf-8')
    return decoded_text


if __name__ == '__main__':
    encode_str = base_encode('Hello, world!!')
    print(encode_str)
    print(base_decode(encode_str))




# !/usr/bin/env python
# -*- coding: UTF-8 -*-

"""
@File   : http_common.py
@Author : bean
@Date   : 2024/9/5 11:28
@Desc   : 基于 flask web 相关扩展
"""
import importlib
import json
import logging
import os
import traceback
from json import JSONEncoder

from flask import jsonify
from pydantic import BaseModel, Field

logger = logging.getLogger(__name__)


def register_blueprints(app, package_name, package_path):
    rv = []
    logger.debug("begin to register blueprint...")
    fn = os.listdir(package_path)
    # for module_name in (fn[:-3] for fn in os.listdir(package_path) if fn.endswith('.py') and fn != '__init__.py'):
    fns = [fn[:-3] for fn in os.listdir(package_path) if fn.endswith('.py') and fn != '__init__.py']
    for module_name in fns:
        module_path = f"{package_name}.{module_name}"

    for module_name in fns:
        module_path = f"{package_name}.{module_name}"
        logger.debug(f"加载 {module_path}...")

        if not module_name.endswith("_view"):
            continue

        try:
            mod = importlib.import_module(module_path)
            blueprint_name = f"{module_name.split('_')[0]}_bp"
            blueprint = getattr(mod, blueprint_name)
            if blueprint is not None:
                app.register_blueprint(blueprint)
                rv.append(blueprint)
                logger.debug(f"注册蓝图 {blueprint_name}")
        except Exception as e:
            logger.warning(f"导入模块 {module_path}异常, 异常信息: {str(e)} \n {str(traceback.format_exc())}")
            continue
    else:
        pass

    logger.debug(f"has finished to register blueprint, total {len(rv)} blueprint views.")

    return rv


class Result(BaseModel):
    code: int = Field(description="返回码", nullable=False, default=0)
    msg: str = Field(description="返回信息", nullable=False, default='')
    data: object = Field(description="返回数据", nullable=True)

    @staticmethod
    def ok(msg='', data=None):
        return Result(code=0, msg=msg, data=data)

    @staticmethod
    def failed(code=500, msg='operation failed', data=None):
        return Result(code=code, msg=msg, data=data)

    def to_json(self):
        data = self.dict()
        return jsonify(data)

    def to_dict(self):
        return self.dict()

    def to_str(self):
        return json.dumps(self.dict(), ensure_ascii=False)


class CustomJSONEncoder(JSONEncoder):
    def default(self, obj):
        if hasattr(obj, 'to_dict'):
            return obj.to_dict()

        # 对于其他不支持的类型，可以调用父类的 default 方法
        return JSONEncoder.default(self, obj)




import datetime
import os

import psutil


def get_uptime():
    """获取服务器的总运行时间"""
    boot_time_timestamp = psutil.boot_time()
    boot_time = datetime.datetime.fromtimestamp(boot_time_timestamp)
    current_time = datetime.datetime.now()
    uptime = current_time - boot_time
    days = uptime.days
    seconds = uptime.seconds
    hours = seconds // 3600
    minutes = (seconds % 3600) // 60
    seconds = seconds % 60

    if days > 0:
        return f"{days}天{hours}小时{minutes}分钟{seconds}秒"
    else:
        return f"{hours}小时{minutes}分钟{seconds}秒"


def get_service_start_time():
    """获取服务的启动时间"""
    try:
        process = psutil.Process(os.getpid())
        start_time_seconds = process.create_time()  # 返回自纪元以来的秒数
        start_time = datetime.datetime.fromtimestamp(start_time_seconds).isoformat()
        return start_time
    except Exception as e:
        return f"无法获取服务启动时间: {str(e)}"
